@@ -178,7 +178,7 @@ class OpenAIManager(AIManager):
         try:
             prompt = self._build_prompt(
                 lines, sentence, current_line, game_title, custom_prompt=custom_prompt)
-            self.logger.debug(f"Generated prompt:\n{prompt}")
+            # self.logger.debug(f"Generated prompt:\n{prompt}")
             # Try with full parameters first, fallback to basic parameters if model doesn't support them
             if self.extra_params_allowed:
                 try:
@@ -216,7 +216,7 @@ class OpenAIManager(AIManager):
                     json_output = text_output[text_output.find(
                         "{"):text_output.rfind("}")+1]
                     text_output = json.loads(json_output)['output']
-            self.logger.debug(f"Received response:\n{text_output}")
+            # self.logger.debug(f"Received response:\n{text_output}")
             return text_output
         except Exception as e:
             self.logger.error(f"OpenAI processing failed: {e}")
@@ -252,7 +252,7 @@ class GeminiAI(AIManager):
             )
             if "2.5" in self.model_name:
                 self.generation_config.thinking_config = types.ThinkingConfig(
-                    thinking_budget=-1
+                    thinking_budget=-1 if '2.5-pro' in self.model_name else 0,
                 )
             self.logger.debug(
                 f"GeminiAIManager initialized with model: {self.model_name}")
@@ -263,6 +263,7 @@ class GeminiAI(AIManager):
     def _build_prompt(self, lines: List[GameLine], sentence: str, current_line: GameLine, game_title: str, custom_prompt=None) -> str:
         prompt = super()._build_prompt(lines, sentence, current_line,
                                        game_title, custom_prompt=custom_prompt)
+        # self.logger.debug(f"Built prompt:\n{prompt}")
         return prompt
 
     def process(self, lines: List[GameLine], sentence: str, current_line: GameLine, game_title: str = "", custom_prompt=None) -> str:
@@ -285,13 +286,12 @@ class GeminiAI(AIManager):
                     ],
                 ),
             ]
-            self.logger.debug(f"Generated prompt:\n{prompt}")
             response = self.client.models.generate_content(
                 model=self.model_name,
                 contents=contents,
                 config=self.generation_config
             )
-            self.logger.debug(f"Full response: {response}")
+            # self.logger.debug(f"Full response: {response}")
             result = response.text.strip()
             self.logger.debug(f"Received response:\n{result}")
             return result
@@ -304,6 +304,7 @@ class GroqAI(AIManager):
     def __init__(self, model, api_key, logger: Optional[logging.Logger] = None):
         super().__init__(GroqAiConfig(model=model, api_key=api_key), logger)
         self.api_key = self.ai_config.api_key
+        self.model_name = model
         try:
             self.client = Groq(api_key=self.api_key)
             self.logger.debug(
@@ -329,7 +330,6 @@ class GroqAI(AIManager):
         try:
             prompt = self._build_prompt(
                 lines, sentence, current_line, game_title, custom_prompt=custom_prompt)
-            self.logger.debug(f"Generated prompt:\n{prompt}")
             completion = self.client.chat.completions.create(
                 model=self.model_name,
                 messages=[{"role": "user", "content": prompt}],
@@ -340,7 +340,7 @@ class GroqAI(AIManager):
                 stop=None,
             )
             result = completion.choices[0].message.content.strip()
-            self.logger.debug(f"Received response:\n{result}")
+            # self.logger.debug(f"Received response:\n{result}")
             return result
         except Exception as e:
             self.logger.error(f"Groq processing failed: {e}")
@@ -497,59 +497,59 @@ if __name__ == '__main__':
 
     # Completely neutral Japanese sentences
     #
-    # lines = [
-    #     GameLine(index=0, text="今日はいい天気ですね。", id=None,
-    #              time=None, prev=None, next=None),
-    #     GameLine(index=1, text="おはようございます。", id=None,
-    #              time=None, prev=None, next=None),
-    #     GameLine(index=2, text="お元気ですか？", id=None,
-    #              time=None, prev=None, next=None),
-    #     GameLine(index=3, text="これはペンです。", id=None,
-    #              time=None, prev=None, next=None),
-    #     GameLine(index=4, text="私は学生です。", id=None,
-    #              time=None, prev=None, next=None),
-    #     GameLine(index=5, text="東京は日本の首都です。", id=None,
-    #              time=None, prev=None, next=None),
-    #     GameLine(index=6, text="こんにちは、元気ですか？", id=None,
-    #              time=None, prev=None, next=None),
-    #     GameLine(index=7, text="さようなら。また会いましょう。", id=None,
-    #              time=None, prev=None, next=None),
-    #     GameLine(index=8, text="ありがとう。助かりました。", id=None,
-    #              time=None, prev=None, next=None),
-    #     GameLine(index=9, text="すみません、道に迷いました。", id=None,
-    #              time=None, prev=None, next=None),
-    #     GameLine(index=10, text="これは本です。", id=None,
-    #              time=None, prev=None, next=None),
-    #     GameLine(index=11, text="私は先生です。", id=None,
-    #              time=None, prev=None, next=None),
-    # ]
+    lines = [
+        GameLine(index=0, text="今日はいい天気ですね。", id=None,
+                 time=None, prev=None, next=None),
+        GameLine(index=1, text="おはようございます。", id=None,
+                 time=None, prev=None, next=None),
+        GameLine(index=2, text="お元気ですか？", id=None,
+                 time=None, prev=None, next=None),
+        GameLine(index=3, text="これはペンです。", id=None,
+                 time=None, prev=None, next=None),
+        GameLine(index=4, text="私は学生です。", id=None,
+                 time=None, prev=None, next=None),
+        GameLine(index=5, text="東京は日本の首都です。", id=None,
+                 time=None, prev=None, next=None),
+        GameLine(index=6, text="こんにちは、元気ですか？", id=None,
+                 time=None, prev=None, next=None),
+        GameLine(index=7, text="さようなら。また会いましょう。", id=None,
+                 time=None, prev=None, next=None),
+        GameLine(index=8, text="ありがとう。助かりました。", id=None,
+                 time=None, prev=None, next=None),
+        GameLine(index=9, text="すみません、道に迷いました。", id=None,
+                 time=None, prev=None, next=None),
+        GameLine(index=10, text="これは本です。", id=None,
+                 time=None, prev=None, next=None),
+        GameLine(index=11, text="私は先生です。", id=None,
+                 time=None, prev=None, next=None),
+    ]
 
-    sentence = "あぁ…もっと奥まで…ダメ…イッちゃう…！"
+    sentence = "おはようございます。"
     current_line = lines[3]
     game_title = "Corrupted Reality"
 
     results = []
 
-    # get_config().ai.provider = AIType.GEMINI.value
-    # models = [
-    #     'gemini-2.5-pro']
+    get_config().ai.provider = AIType.GEMINI.value
+    models = [
+        'gemini-2.5-flash']
 
-    # for model in models:
-    #     get_config().ai.gemini_model = model
-    #     start_time = time.time()
-    #     result = get_ai_prompt_result(lines, sentence, current_line, game_title, True)
-    #     results.append({"model": model, "response": result, "time": time.time() - start_time, "iteration": 1})
-
-    get_config().ai.provider = AIType.OPENAI.value
-    get_config().ai.open_ai_url = "https://api.openai.com/v1"
-    get_config().ai.open_ai_model = "gpt-5-nano-2025-08-07"
-
-    for i in range(5):
+    for model in models:
+        get_config().ai.gemini_model = model
         start_time = time.time()
-        result = get_ai_prompt_result(
-        lines, sentence, current_line, game_title, True)
-        results.append({"model": get_config().ai.open_ai_model,
-                       "response": result, "time": time.time() - start_time, "iteration": i})
+        result = get_ai_prompt_result(lines, sentence, current_line, game_title, True)
+        results.append({"model": model, "response": result, "time": time.time() - start_time, "iteration": 1})
+
+    # get_config().ai.provider = AIType.OPENAI.value
+    # get_config().ai.open_ai_url = "https://api.openai.com/v1"
+    # get_config().ai.open_ai_model = "gpt-5-nano-2025-08-07"
+
+    # for i in range(5):
+    #     start_time = time.time()
+    #     result = get_ai_prompt_result(
+    #     lines, sentence, current_line, game_title, True)
+    #     results.append({"model": get_config().ai.open_ai_model,
+    #                    "response": result, "time": time.time() - start_time, "iteration": i})
 
     # get_config().ai.provider = AIType.OPENAI.value
     # models = [
