@@ -1,7 +1,5 @@
 # There should be no imports here, as any error will crash the program.
 # All imports should be done in the try/except block below.
-
-
 def handle_error_in_initialization(e):
     """Handle errors that occur during initialization."""
     logger.exception(e, exc_info=True)
@@ -34,7 +32,7 @@ try:
 
     import keyboard
     import ttkbootstrap as ttk
-    from PIL import Image, ImageDraw
+    from PIL import Image
     from pystray import Icon, Menu, MenuItem
     from watchdog.events import FileSystemEventHandler
     from watchdog.observers import Observer
@@ -49,7 +47,7 @@ try:
     logger.debug(f"[Import] configuration: {time.time() - start_time:.3f}s")
     
     start_time = time.time()
-    from GameSentenceMiner.util.get_overlay_coords import OverlayThread
+    from GameSentenceMiner.util.get_overlay_coords import init_overlay_processor
     from GameSentenceMiner.util.gsm_utils import remove_html_and_cloze_tags, add_srt_line
     logger.debug(f"[Import] get_overlay_coords (OverlayThread, remove_html_and_cloze_tags): {time.time() - start_time:.3f}s")
 
@@ -62,7 +60,7 @@ try:
     logger.debug(f"[Import] vad_processor: {time.time() - start_time:.3f}s")
 
     start_time = time.time()
-    from GameSentenceMiner.util.downloader.download_tools import download_obs_if_needed, download_ffmpeg_if_needed
+    from GameSentenceMiner.util.downloader.download_tools import download_obs_if_needed, download_ffmpeg_if_needed, write_obs_configs, download_oneocr_dlls_if_needed
     logger.debug(
         f"[Import] download_tools (download_obs_if_needed, download_ffmpeg_if_needed): {time.time() - start_time:.3f}s")
 
@@ -146,6 +144,8 @@ procs_to_close = []
 settings_window: config_gui.ConfigApp = None
 obs_paused = False
 root = None
+file_watcher_observer = None  # Global observer for file watching
+file_watcher_path = None  # Track the currently watched path
 warnings.simplefilter("ignore", DeprecationWarning)
 
 
@@ -189,11 +189,8 @@ class VideoToAudioHandler(FileSystemEventHandler):
             return
         try:
             if anki.card_queue and len(anki.card_queue) > 0:
-                last_note, anki_card_creation_time, selected_lines = anki.card_queue.pop(
+                last_note, anki_card_creation_time, selected_lines, mined_line = anki.card_queue.pop(
                     0)
-            elif get_config().features.backfill_audio:
-                last_note = anki.get_cards_by_sentence(
-                    gametext.current_line_after_regex)
             else:
                 logger.info(
                     "Replay buffer initiated externally. Skipping processing.")
@@ -204,9 +201,6 @@ class VideoToAudioHandler(FileSystemEventHandler):
             if not last_note:
                 if get_config().anki.update_anki:
                     last_note = anki.get_last_anki_card()
-                if get_config().features.backfill_audio:
-                    last_note = anki.get_cards_by_sentence(
-                        gametext.current_line_after_regex)
 
             note, last_note = anki.get_initial_card_info(
                 last_note, selected_lines)
@@ -219,11 +213,11 @@ class VideoToAudioHandler(FileSystemEventHandler):
             full_text = ''
             if selected_lines:
                 start_line = selected_lines[0]
-                mined_line = get_mined_line(last_note, selected_lines)
+                # mined_line = get_mined_line(last_note, selected_lines)
                 line_cutoff = selected_lines[-1].get_next_time()
                 full_text = remove_html_and_cloze_tags(note['fields'][get_config().anki.sentence_field])
             else:
-                mined_line = get_text_event(last_note)
+                # mined_line = get_text_event(last_note)
                 if mined_line:
                     start_line = mined_line
                     if mined_line.next:
@@ -362,6 +356,7 @@ def initial_checks():
     try:
         subprocess.run(GameSentenceMiner.util.configuration.ffmpeg_base_command_list)
         logger.debug("FFMPEG is installed and accessible.")
+        
     except FileNotFoundError:
         logger.error(
             "FFmpeg not found, please install it and add it to your PATH.")
@@ -381,49 +376,12 @@ def register_hotkeys():
 
 
 def get_screenshot():
-    # try:
     last_note = anki.get_last_anki_card()
     gsm_state.anki_note_for_screenshot = last_note
     gsm_state.line_for_screenshot = get_mined_line(last_note, get_all_lines())
     obs.save_replay_buffer()
-    #     image = obs.get_screenshot()
-    #     wait_for_stable_file(image, timeout=3)
-    #     if not image:
-    #         raise Exception("Failed to get Screenshot from OBS")
-    #     encoded_image = ffmpeg.process_image(image)
-    #     if get_config().anki.update_anki and get_config().screenshot.screenshot_hotkey_updates_anki:
-    #         last_note = anki.get_last_anki_card()
-    #         if get_config().features.backfill_audio:
-    #             last_note = anki.get_cards_by_sentence(gametext.current_line)
-    #         if last_note:
-    #             anki.add_image_to_card(last_note, encoded_image)
-    #             notification.send_screenshot_updated(last_note.get_field(get_config().anki.word_field))
-    #             if get_config().features.open_anki_edit:
-    #                 notification.open_anki_card(last_note.noteId)
-    #         else:
-    #             notification.send_screenshot_saved(encoded_image)
-    #     else:
-    #         notification.send_screenshot_saved(encoded_image)
-    # except Exception as e:
-    #     logger.error(f"Failed to get Screenshot: {e}")
 
 
-# def create_image():
-#     """Create a simple pickaxe icon."""
-#     width, height = 64, 64
-#     image = Image.new("RGBA", (width, height), (0, 0, 0, 0))  # Transparent background
-#     draw = ImageDraw.Draw(image)
-#
-#     # Handle (rectangle)
-#     handle_color = (139, 69, 19)  # Brown color
-#     draw.rectangle([(30, 15), (34, 50)], fill=handle_color)
-#
-#     # Blade (triangle-like shape)
-#     blade_color = (192, 192, 192)  # Silver color
-#     draw.polygon([(15, 15), (49, 15), (32, 5)], fill=blade_color)
-#
-#     return image
-
 def create_image():
     image_path = os.path.join(os.path.dirname(
         __file__), "assets", "pickaxe.png")
@@ -639,6 +597,14 @@ def cleanup():
         if gsm_tray:
             gsm_tray.stop()
 
+        # Stop file watcher observer
+        if file_watcher_observer:
+            try:
+                file_watcher_observer.stop()
+                file_watcher_observer.join()
+            except Exception as e:
+                logger.error(f"Error stopping file watcher observer: {e}")
+
         for video in gsm_state.videos_to_remove:
             try:
                 if os.path.exists(video):
@@ -666,6 +632,43 @@ def handle_exit():
     return _handle_exit
 
 
+def start_file_watcher():
+    """Start or restart the file watcher with current config."""
+    global file_watcher_observer, file_watcher_path
+    
+    # Stop existing observer if running
+    if file_watcher_observer:
+        try:
+            file_watcher_observer.stop()
+            file_watcher_observer.join(timeout=2)
+            logger.info("Stopped existing file watcher")
+        except Exception as e:
+            logger.error(f"Error stopping file watcher: {e}")
+    
+    # Create and start new observer
+    watch_path = get_config().paths.folder_to_watch
+    os.makedirs(watch_path, exist_ok=True)
+    
+    file_watcher_observer = Observer()
+    file_watcher_observer.schedule(VideoToAudioHandler(), watch_path, recursive=False)
+    file_watcher_observer.start()
+    file_watcher_path = watch_path
+    logger.info(f"File watcher started for: {watch_path}")
+
+
+def on_config_changed():
+    """Called when config is saved/changed. Restarts file watcher if path changed."""
+    global file_watcher_path
+    
+    new_path = get_config().paths.folder_to_watch
+    
+    if file_watcher_path != new_path:
+        logger.info(f"Watch path changed from '{file_watcher_path}' to '{new_path}', restarting file watcher...")
+        start_file_watcher()
+    else:
+        logger.debug("Config changed, but watch path unchanged - no restart needed")
+
+
 def initialize(reloading=False):
     global obs_process
     if not reloading:
@@ -673,6 +676,8 @@ def initialize(reloading=False):
         if is_windows():
             download_obs_if_needed()
             download_ffmpeg_if_needed()
+            download_oneocr_dlls_if_needed()
+            write_obs_configs(obs.get_base_obs_dir())
             if shutil.which("ffmpeg") is None:
                 os.environ["PATH"] += os.pathsep + \
                     os.path.dirname(get_ffmpeg_path())
@@ -745,8 +750,12 @@ def async_loop():
         await obs.connect_to_obs(connections=3, check_output=True)
         await register_scene_switcher_callback()
         await check_obs_folder_is_correct()
+        
+        # Start file watcher after OBS path is verified/corrected
+        start_file_watcher()
+        
         vad_processor.init()
-        OverlayThread().start()
+        await init_overlay_processor()
 
         # Keep loop alive
         # if is_beangate:
@@ -829,10 +838,6 @@ async def async_main(reloading=False):
         settings_window = config_gui.ConfigApp(root)
         gsm_state.config_app = settings_window
         initialize_async()
-        observer = Observer()
-        observer.schedule(VideoToAudioHandler(),
-                          get_config().paths.folder_to_watch, recursive=False)
-        observer.start()
         if is_windows():
             register_hotkeys()
 
@@ -863,16 +868,11 @@ async def async_main(reloading=False):
             #     audio_path="C:/path/to/my/audio.mp3",
             #     translation="Hello world! How are you?"))
             settings_window.add_save_hook(gsm_tray.update_icon)
+            settings_window.add_save_hook(on_config_changed)
             settings_window.on_exit = exit_program
             root.mainloop()
         except KeyboardInterrupt:
             cleanup()
-
-        try:
-            observer.stop()
-            observer.join()
-        except Exception as e:
-            logger.error(f"Error stopping observer: {e}")
     except Exception as e:
         handle_error_in_initialization(e)
 
